# tornado_discovery

Just a pure python3 module for service discovery.
Include some basic classes for develop distributed services.

# install
```bash
# install from pip
$ pip3 install -U tornado_discovery
# or install from source code
$ cd ./tornado_discovery
$ python3 ./setup.py install
```

# test & try it
```bash
# run listener
$ cd ./tornado_discovery/test
$ python3 ./test_discovery_listener.py

# run registrant
$ cd ./tornado_discovery/test
$ python3 ./test_discovery_registrant.py
```

